@@ -76,7 +76,7 @@
  * URL:
  *   http://modurl.kldp.net/
  *
- * $Id: mod_url.c,v 1.14 2007/11/20 17:24:56 oops Exp $
+ * $Id: mod_url.c,v 1.16 2008/10/21 11:19:10 oops Exp $
  */
 
 /*
@@ -111,7 +111,7 @@ typedef struct {
 	size_t  len;
 	size_t  flen;
 	size_t  tlen;
-	size_t  ret;
+	short   ret;
 	short   alloc;
 } iconv_s;
 
@@ -292,6 +292,8 @@ void check_redurl_iconv (request_rec * r, urlconfig * cfg, iconv_s * ic, char *
 		redurl_mem_error (r, APLOG_MARK, "ic->uri");
 		ap_log_rerror(APLOG_MARK, APLOG_NOERRNO|APLOG_DEBUG, r,
 				"check_redurl_iconv: iconv convert end   -------------------");
+
+		iconv_close (cfg->cd);
 		return;
 	} else
 		memset (ic->uri, 0, sizeof (char) * tlen);
@@ -305,6 +307,8 @@ void check_redurl_iconv (request_rec * r, urlconfig * cfg, iconv_s * ic, char *
 	ic->tlen = tlen;
 	ic->flen = flen;
 
+	iconv_close (cfg->cd);
+
 	ap_log_rerror(APLOG_MARK, APLOG_NOERRNO|APLOG_DEBUG, r,
 			"  Oirg       => %s (%d)", s_uri, ic->len);
 	ap_log_rerror(APLOG_MARK, APLOG_NOERRNO|APLOG_DEBUG, r,
